package com.jjt.hl.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.hl.domain.HlMetrics;
import com.jjt.hl.service.IHlMetricsService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度指标Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags="业务模型健康度指标")
@RestController
@RequestMapping("/hl/hm")
public class HlMetricsController extends BaseController
{
    @Resource
    private IHlMetricsService hlMetricsService;

    /**
     * 查询业务模型健康度指标列表
     */
    @ApiOperation("查询业务模型健康度指标列表")
    @PreAuthorize("@ss.hasPermi('hl:hm:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlMetrics hlMetrics)
    {
        startPage();
        List<HlMetrics> list = hlMetricsService.selectHlMetricsList(hlMetrics);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度指标列表
     */
    @ApiOperation("导出业务模型健康度指标列表")
    @PreAuthorize("@ss.hasPermi('hl:hm:export')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlMetrics hlMetrics)
    {
        List<HlMetrics> list = hlMetricsService.selectHlMetricsList(hlMetrics);
        ExcelUtil<HlMetrics> util = new ExcelUtil<HlMetrics>(HlMetrics.class);
        util.exportExcel(response, list, "业务模型健康度指标数据");
    }

    /**
     * 获取业务模型健康度指标详细信息
     */
    @ApiOperation("获取业务模型健康度指标详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hm:query')")
    @GetMapping(value = "/{hlMetricsId}")
    public AjaxResult getInfo(@PathVariable("hlMetricsId") Long hlMetricsId)
    {
        return success(hlMetricsService.selectHlMetricsByHlMetricsId(hlMetricsId));
    }

    /**
     * 新增业务模型健康度指标
     */
    @ApiOperation("新增业务模型健康度指标")
    @PreAuthorize("@ss.hasPermi('hl:hm:add')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlMetrics hlMetrics)
    {
        return toAjax(hlMetricsService.insertHlMetrics(hlMetrics));
    }

    /**
     * 修改业务模型健康度指标
     */
    @ApiOperation("修改业务模型健康度指标")
    @PreAuthorize("@ss.hasPermi('hl:hm:edit')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlMetrics hlMetrics)
    {
        return toAjax(hlMetricsService.updateHlMetrics(hlMetrics));
    }

    /**
     * 删除业务模型健康度指标
     */
    @ApiOperation("删除业务模型健康度指标")
    @PreAuthorize("@ss.hasPermi('hl:hm:remove')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.DELETE)
	@DeleteMapping("/{hlMetricsIds}")
    public AjaxResult remove(@PathVariable Long[] hlMetricsIds)
    {
        return toAjax(hlMetricsService.deleteHlMetricsByHlMetricsIds(hlMetricsIds));
    }
}
