package com.jjt.hl.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.hl.domain.HlScore;
import com.jjt.hl.service.IHlScoreService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康度分数记录Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags="健康度分数记录")
@RestController
@RequestMapping("/hl/hs")
public class HlScoreController extends BaseController
{
    @Resource
    private IHlScoreService hlScoreService;

    /**
     * 查询健康度分数记录列表
     */
    @ApiOperation("查询健康度分数记录列表")
    @PreAuthorize("@ss.hasPermi('hl:hs:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlScore hlScore)
    {
        startPage();
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }

    /**
     * 导出健康度分数记录列表
     */
    @ApiOperation("导出健康度分数记录列表")
    @PreAuthorize("@ss.hasPermi('hl:hs:export')")
    @Log(title = "健康度分数记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlScore hlScore)
    {
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        ExcelUtil<HlScore> util = new ExcelUtil<HlScore>(HlScore.class);
        util.exportExcel(response, list, "健康度分数记录数据");
    }

    /**
     * 获取健康度分数记录详细信息
     */
    @ApiOperation("获取健康度分数记录详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hs:query')")
    @GetMapping(value = "/{hlScoreId}")
    public AjaxResult getInfo(@PathVariable("hlScoreId") Long hlScoreId)
    {
        return success(hlScoreService.selectHlScoreByHlScoreId(hlScoreId));
    }

    /**
     * 新增健康度分数记录
     */
    @ApiOperation("新增健康度分数记录")
    @PreAuthorize("@ss.hasPermi('hl:hs:add')")
    @Log(title = "健康度分数记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlScore hlScore)
    {
        return toAjax(hlScoreService.insertHlScore(hlScore));
    }

    /**
     * 修改健康度分数记录
     */
    @ApiOperation("修改健康度分数记录")
    @PreAuthorize("@ss.hasPermi('hl:hs:edit')")
    @Log(title = "健康度分数记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlScore hlScore)
    {
        return toAjax(hlScoreService.updateHlScore(hlScore));
    }

    /**
     * 删除健康度分数记录
     */
    @ApiOperation("删除健康度分数记录")
    @PreAuthorize("@ss.hasPermi('hl:hs:remove')")
    @Log(title = "健康度分数记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{hlScoreIds}")
    public AjaxResult remove(@PathVariable Long[] hlScoreIds)
    {
        return toAjax(hlScoreService.deleteHlScoreByHlScoreIds(hlScoreIds));
    }
}
